'''
Created on 2022-04-01

@author: wf
'''
import skg

class Version(object):
    '''
    Version handling for pysotsog
    '''
    name="pysotsog"
    description='''python Library for Scholars to achieve "Standing on the shoulders of giants"'''
    version=skg.__version__
    date = '2022-11-16'
    updated = '2022-11-16'

        